import { defineStore } from "pinia";
import { ref } from "vue";
import useUserStore from "@/stores/useUserStore";

const useNavDataStore = defineStore("nav", () => {
  const userStore = useUserStore();

  const selectedBuildingOrd = ref(null);
  const menuList = ref([]);

  const setSelectedBuildingOrd = (ord) => {
    selectedBuildingOrd.value = ord;
  };

  const getNavData = () => {
    if (window.require && window.requirejs) {
      window.requirejs(["baja!"], (baja) => {
        console.log("進入 bajaSubscriber 準備執行 BQL 訂閱");

        const ord = `local:|foxs:|file:^UI_Framework/System/S_${userStore.userRole}.nav`;

        baja.Ord.make(ord)
          .get()
          .then((nav) => {
            if (!nav || !nav.$fileData) {
              console.error("未能取得有效 NAV 資料！");
            } else {
              console.log("成功讀取 NAV 資料", nav);
              // 將 XML 文本解析成 DOM 結構
              fetch(nav.$fileData.read)
                .then((response) => response.text())
                .then((xmlText) => parseXmlData(xmlText))
                .catch((err) => {
                  console.error(`讀取 NAV 檔案失敗：${err.message}`);
                });
            }
          })
          .catch((err) => {
            console.error(`讀取 NAV 檔案失敗：${err.message}`);
          });
      });
    } else {
      console.error("未能載入 Baja 環境，請確認依賴已正確加載。");
    }
  };

  const parseXmlData = (xmlText) => {
    const parser = new DOMParser();
    const xmlDoc = parser.parseFromString(xmlText, "application/xml");
    const navNodes = xmlDoc.getElementsByTagName("node");

    if (!navNodes.length) {
      console.error("無法解析 NAV XML 結構。");
      return;
    }

    // 只處理第一個節點
    const firstNode = navNodes[0];
    menuList.value = firstNode ? [parseNode(firstNode, "1")] : []; 
    console.log("menuList.value", menuList.value);
  };

  // 遞迴解析 XML 結構
  const parseNode = (node, key) => {
    const name = node.getAttribute("name");
    const ord = node.getAttribute("ord");
    const icon = node.getAttribute("icon");

    // 處理子節點遞迴
    const childrenNodes = Array.from(node.children);
    const children = childrenNodes.length > 0 ? childrenNodes.map((child, index) => parseNode(child, `${key}-${index + 1}`)) : null;

    return {
      key,
      label: name,
      title: name,
      icon,
      ord,
      children,
    };
  };

  return {
    selectedBuildingOrd,
    setSelectedBuildingOrd,
    menuList,
    getNavData,
  };
});

export default useNavDataStore;