import { defineStore } from "pinia";
import { ref } from "vue";
import useUserStore from "@/stores/useUserStore";

const useNiagaraDataStore = defineStore("niagara", () => {
  const userStore = useUserStore();

  const systemList = ref([]);
  const headerList = ref([]);
  const weatherList = ref([]);
  const alarmList = ref([]);
  const userList = ref([]);
  const DynamicList = ref([]);

  const getSystemData = () => {
    if (window.require && window.requirejs) {
      window.requirejs(["baja!"], (baja) => {
        console.log("進入 bajaSubscriber 準備執行 BQL 訂閱");

        const ord = `local:|foxs:|file:^UI_Framework/Function/F_${userStore.userRole}.nav`;

        baja.Ord.make(ord)
          .get()
          .then((nav) => {
            if (!nav || !nav.$fileData) {
              console.error("未能取得有效 NAV 資料！");
            } else {
              console.log("成功讀取 NAV 資料", nav);
              // 將 XML 文本解析成 DOM 結構
              fetch(nav.$fileData.read)
                .then((response) => response.text())
                .then((xmlText) => parseXmlData(xmlText))
                .catch((err) => {
                  console.error(`讀取 NAV 檔案失敗：${err.message}`);
                });
            }
          })
          .catch((err) => {
            console.error(`讀取 NAV 檔案失敗：${err.message}`);
          });
      });
    } else {
      console.error("未能載入 Baja 環境，請確認依賴已正確加載。");
    }
  };

  const parseXmlData = (xmlText) => {
    const parser = new DOMParser();
    const xmlDoc = parser.parseFromString(xmlText, "application/xml");
    const navNodes = xmlDoc.getElementsByTagName("node");

    if (!navNodes.length) {
      console.error("無法解析 NAV XML 結構。");
      return;
    }

    // 轉換 XML node 結構為物件
    const firstNode = navNodes[0];
    systemList.value = firstNode ? [parseNode(firstNode, "1")] : [];
    console.log("systemList.value", systemList.value);

    const Fix_Node = systemList.value[0].children.find(
      (node) => node.name === "Fix_Item"
    );
    const Dynamic_Node = systemList.value[0].children.find(
      (node) => node.name === "Dynamic_Item"
    );

    // 查找 "Fix_Item" 節點下各節點的list
    if (Fix_Node && Fix_Node.children) {
      headerList.value =
        Fix_Node.children.find((node) => node.name === "header") || null;
      weatherList.value =
        Fix_Node.children.find((node) => node.name === "weather") || null;
      alarmList.value =
        Fix_Node.children.find((node) => node.name === "alarmlist") || null;
      userList.value =
        Fix_Node.children.find((node) => node.name === "user") || null;
    }

    if (Dynamic_Node && Dynamic_Node.children) {
      DynamicList.value = Dynamic_Node || null;
    }

    console.log(
      "Fix_Item 節點下各節點的list",
      headerList.value,
      weatherList.value,
      alarmList.value,
      userList.value
    );
    console.log(
      "Dynamic_Item 節點下各節點的list",
      DynamicList.value
    );
  };

  // 遞迴解析 XML 結構
  const parseNode = (node, key) => {
    const name = node.getAttribute("name");
    const ord = node.getAttribute("ord");
    const icon = node.getAttribute("icon");

    // 處理子節點遞迴
    const childrenNodes = Array.from(node.children);
    const children =
      childrenNodes.length > 0
        ? childrenNodes.map((child, index) =>
            parseNode(child, `${key}-${index + 1}`)
          )
        : null;

    return {
      key,
      name,
      ord,
      children,
      icon,
    };
  };

  const findNodeByName = (nodes, name) => {
    for (const node of nodes) {
      if (node.name === name) {
        return node;
      }
      if (node.children) {
        const result = findNodeByName(node.children, name);
        if (result) return result;
      }
    }
    return null;
  };

  return {
    systemList,
    headerList,
    weatherList,
    alarmList,
    userList,
    DynamicList,
    getSystemData,
  };
});
export default useNiagaraDataStore;
